@@ -23,6 +23,9 @@ import regex
 from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
 from ..utils.utils import ModuleInfo
 
+ValueDict = dict[str, str | int | bool]
+ValuesTuple = tuple[int, int, int, int]
+
 KEYS = ("euro", "mark", "ost", "schwarz")
 MULTIPLIERS = (1, 2, 4, 20)
 
@@ -116,7 +119,7 @@ async def continuation_string(
         if ins_kino_gehen == "ins Kino gehen"
         else int(max(round(price // 8) // 2, 50))
     )
-    _rand = random.Random(f"{price}|{values}|{ins_kino_gehen}")
+    rand = random.Random(f"{price}|{values}|{ins_kino_gehen}")
     kino_count: int = values[-1] // price_ostmark
     output = [
         "Und ich weiß nicht, ob ihr das noch wisst, aber man konnte locker für",
@@ -143,7 +146,7 @@ async def continuation_string(
             output.append("...äh...")
         output.append(f"{num_to_string(euro)} Euro bezahlen.")
         output.append(
-            _rand.choice(
+            rand.choice(
                 (
                     "Ja! Ja! Ich weiß, was ihr denkt!",
                     "Ja, ja, ich weiß, was ihr denkt!",
@@ -173,10 +176,6 @@ async def continuation_string(
     return " ".join(output)
 
 
-ValueDict = dict[str, str | int | bool]
-ValuesTuple = tuple[int, int, int, int]
-
-
 def convert(euro: int) -> ValuesTuple:
     """Convert a number to the german representation of a number."""
     return cast(ValuesTuple, tuple(euro * _m for _m in MULTIPLIERS))
@@ -189,7 +188,7 @@ async def get_value_dict(
     """Create the value dict base on the euro."""
     values = convert(euro)
     value_dict: ValueDict = {}
-    for key, val in zip(KEYS, values):
+    for key, val in zip(KEYS, values, strict=True):
         value_dict[key] = val
         value_dict[key + "_str"] = num_to_string(val)
 
@@ -221,7 +220,7 @@ class CurrencyConverter(HTMLRequestHandler):
         for i, key, num_str in arg_list:
             euro = string_to_num(num_str, MULTIPLIERS[i])
             if euro is not None:
-                value_dict: ValueDict = await get_value_dict(
+                value_dict = await get_value_dict(
                     euro, ins_kino_gehen=self.get_argument("text", None)
                 )
                 if too_many_params:
@@ -279,7 +278,9 @@ class CurrencyConverterAPI(APIRequestHandler, CurrencyConverter):
             return
 
         if value_dict is None:
-            return await self.finish(dict(zip(KEYS, [None] * len(KEYS))))
+            return await self.finish(
+                dict(zip(KEYS, [None] * len(KEYS), strict=True))
+            )
 
         for key in KEYS:
             value_dict[key] = value_dict.pop(f"{key}_str")
