@@ -16,6 +16,7 @@
 from __future__ import annotations
 
 from collections import Counter
+from collections.abc import Set
 from dataclasses import asdict, dataclass, field
 from functools import cache
 
@@ -120,7 +121,7 @@ def fix_letter_counter_crossword_mode(
 
 @cache
 def filter_words(
-    words: frozenset[str] | str,
+    words: Set[str] | str,
     pattern: regex.Pattern[str],
     input_letters: str,
     crossword_mode: bool = False,
@@ -224,7 +225,7 @@ def _solve_hangman(
 ) -> Hangman:
     """Generate a hangman object based on the input and return it."""
     if language not in LANGUAGES:
-        raise HTTPError(400, reason=f"'{language}' is an invalid language")
+        raise HTTPError(400, reason=f"{language!r} is an invalid language")
 
     input_str = fix_input_str(input_str)
     invalid = fix_invalid(invalid)
@@ -232,7 +233,7 @@ def _solve_hangman(
     input_len = len(input_str)
 
     # to be short (is only the key of the words dict in __init__.py)
-    filename = f"words_{language}/{input_len}"
+    filename = f"{language}/{input_len}"
 
     if filename not in FILE_NAMES:
         # no words with the length
