@@ -55,6 +55,9 @@ LICENSES = {
     "magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt": (
         "https://www.gnu.org/licenses/agpl-3.0.html"
     ),
+    "magnet:?xt=urn:btih:d3d9a9a6595521f9666a5e94cc830dab83b65699&dn=expat.txt": (
+        "https://www.jclark.com/xml/copying.txt"
+    ),
 }
 
 
