@@ -31,12 +31,12 @@ import types
 from asyncio import AbstractEventLoop
 from asyncio.runners import _cancel_all_tasks  # type: ignore[attr-defined]
 from base64 import b64encode
-from collections.abc import Callable, Coroutine, Iterable
+from collections.abc import Callable, Coroutine, Iterable, MutableSequence
 from configparser import ConfigParser
 from hashlib import sha3_512, sha256
 from multiprocessing import process
 from pathlib import Path
-from typing import Any, Final, cast
+from typing import Any, Final, Literal, cast
 from zoneinfo import ZoneInfo
 
 import orjson
@@ -92,6 +92,15 @@ from .utils.utils import (
     time_function,
 )
 
+try:
+    import perf8  # type: ignore[import]
+except ImportError:
+    perf8 = None
+
+ES_WHAT_LITERAL = Literal[  # pylint: disable=invalid-name
+    "component_templates", "index_templates", "ingest_pipelines"
+]
+
 IGNORED_MODULES: Final[set[str]] = {
     "patches.*",
     "static.*",
@@ -127,8 +136,10 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
             module_infos.extend(_module_infos)
             loaded_modules.append(potential_module)
             LOGGER.debug(
-                "Found module_infos in %s.__init__.py, "
-                "not searching in other modules in the package.",
+                (
+                    "Found module_infos in %s.__init__.py, "
+                    "not searching in other modules in the package."
+                ),
                 potential_module,
             )
             continue
@@ -173,7 +184,7 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
 
 def get_module_infos_from_module(
     module_name: str,
-    errors: list[str],  # gets modified
+    errors: MutableSequence[str],  # gets modified
     ignore_not_found: bool = False,
 ) -> None | list[ModuleInfo]:
     """Get the module infos based on a module."""
@@ -200,7 +211,7 @@ def get_module_infos_from_module(
         errors.append(
             f"{module_name} has no 'get_module_info' and no 'get_module_infos' "
             "method. Please add at least one of the methods or add "
-            f"'{module_name.rsplit('.', 1)[0]}.*' or '{module_name}' to "
+            f"'{module_name.rsplit('.', 1)[0]}.*' or {module_name!r} to "
             "IGNORED_MODULES."
         )
         return None
@@ -253,7 +264,7 @@ def sort_module_infos(module_infos: list[ModuleInfo]) -> None:
             break
 
 
-def get_all_handlers(module_infos: tuple[ModuleInfo, ...]) -> list[Handler]:
+def get_all_handlers(module_infos: Iterable[ModuleInfo]) -> list[Handler]:
     """
     Parse the module information and return the handlers in a tuple.
 
@@ -591,25 +602,25 @@ def setup_apm(app: Application) -> None:  # pragma: no cover
     }
 
     script_options = [
-        f"serviceName:'{app.settings['ELASTIC_APM']['SERVICE_NAME']}'",
-        f"serviceVersion:'{app.settings['ELASTIC_APM']['SERVICE_VERSION']}'",
-        f"environment:'{app.settings['ELASTIC_APM']['ENVIRONMENT']}'",
+        f"serviceName:{app.settings['ELASTIC_APM']['SERVICE_NAME']!r}",
+        f"serviceVersion:{app.settings['ELASTIC_APM']['SERVICE_VERSION']!r}",
+        f"environment:{app.settings['ELASTIC_APM']['ENVIRONMENT']!r}",
     ]
 
     rum_server_url = app.settings["ELASTIC_APM"]["RUM_SERVER_URL"]
 
     if rum_server_url is None:
         script_options.append(
-            f"serverUrl:'{app.settings['ELASTIC_APM']['SERVER_URL']}'"
+            f"serverUrl:{app.settings['ELASTIC_APM']['SERVER_URL']!r}"
         )
     elif rum_server_url:
-        script_options.append(f"serverUrl:'{rum_server_url}'")
+        script_options.append(f"serverUrl:{rum_server_url!r}")
     else:
         script_options.append("serverUrl:window.location.origin")
 
     if app.settings["ELASTIC_APM"]["RUM_SERVER_URL_PREFIX"]:
         script_options.append(
-            f"serverUrlPrefix:'{app.settings['ELASTIC_APM']['RUM_SERVER_URL_PREFIX']}'"
+            f"serverUrlPrefix:{app.settings['ELASTIC_APM']['RUM_SERVER_URL_PREFIX']!r}"
         )
 
     app.settings["ELASTIC_APM"]["INLINE_SCRIPT"] = (
@@ -691,9 +702,8 @@ def setup_elasticsearch(app: Application) -> None | AsyncElasticsearch:
 
 async def check_elasticsearch(app: Application) -> None:  # pragma: no cover
     """Check Elasticsearch."""
-    # pylint: disable=invalid-name
     while not EVENT_SHUTDOWN.is_set():  # pylint: disable=while-used
-        es: AsyncElasticsearch = cast(
+        es: AsyncElasticsearch = cast(  # pylint: disable=invalid-name
             AsyncElasticsearch, app.settings.get("ELASTICSEARCH")
         )
         try:
@@ -716,29 +726,23 @@ async def check_elasticsearch(app: Application) -> None:  # pragma: no cover
         await asyncio.sleep(20)
 
 
-async def setup_elasticsearch_configs(  # noqa: C901
+async def setup_elasticsearch_configs(
     elasticsearch: AsyncElasticsearch,
     prefix: str,
 ) -> None:
     """Setup Elasticsearch configs."""  # noqa: D401
-    # pylint: disable=too-complex, too-many-branches
-    get: Callable[..., Coroutine[None, None, dict[str, Any]]]
-    put: Callable[..., Coroutine[None, None, dict[str, Any]]]
+    spam: list[Coroutine[None, None, None | dict[str, Any]]]
+
     for i in range(3):
-        if i == 0:  # pylint: disable=compare-to-zero
-            what = "ingest_pipelines"
-            get = elasticsearch.ingest.get_pipeline
-            put = elasticsearch.ingest.put_pipeline
-        elif i == 1:
-            what = "component_templates"
-            get = elasticsearch.cluster.get_component_template
-            put = elasticsearch.cluster.put_component_template
-        elif i == 2:
-            what = "index_templates"
-            get = elasticsearch.indices.get_index_template
-            put = elasticsearch.indices.put_index_template
+        spam = []
+
+        what = cast(
+            ES_WHAT_LITERAL,
+            ["ingest_pipelines", "component_templates", "index_templates"][i],
+        )
 
         base_path = Path(os.path.join(DIR, "elasticsearch", what))
+
         for path in base_path.rglob("*.json"):
             if not path.is_file():
                 LOGGER.warning("%s is not a file", path)
@@ -748,35 +752,67 @@ async def setup_elasticsearch_configs(  # noqa: C901
                 path.read_bytes().replace(b"{prefix}", prefix.encode("ASCII"))
             )
 
-            name = (
-                f"{prefix}-{str(path.relative_to(base_path))[:-5].replace('/', '-')}"
+            name = f"{prefix}-{str(path.relative_to(base_path))[:-5].replace('/', '-')}"
+
+            spam.append(
+                setup_elasticsearch_config(
+                    elasticsearch, what, body, name, path
+                )
             )
 
-            try:
-                if what == "ingest_pipelines":
-                    current = await get(id=name)
-                    current_version = current[name].get("version", 1)
-                else:
-                    current = await get(
-                        name=name,
-                        params={"filter_path": f"{what}.name,{what}.version"},
-                    )
-                    current_version = current[what][0].get("version", 1)
-            except NotFoundError:
-                current_version = 0
+        await asyncio.gather(*spam)
 
-            if current_version < body.get("version", 1):
-                if what == "ingest_pipelines":
-                    await put(id=name, body=body)
-                else:
-                    await put(name=name, body=body)
-            elif current_version > body.get("version", 1):
-                LOGGER.warning(
-                    "%s has version %s. The version in Elasticsearch is %s!",
-                    path,
-                    body.get("version", 1),
-                    current_version,
-                )
+
+async def setup_elasticsearch_config(
+    es: AsyncElasticsearch,  # pylint: disable=invalid-name
+    what: ES_WHAT_LITERAL,
+    body: dict[str, Any],
+    name: str,
+    path: str | Path = "<unknown>",
+) -> None | dict[str, Any]:
+    """Setup Elasticsearch config."""  # noqa: D401
+    get: Callable[..., Coroutine[None, None, dict[str, Any]]]
+    put: Callable[..., Coroutine[None, None, dict[str, Any]]]
+
+    if what == "component_templates":
+        get = es.cluster.get_component_template
+        put = es.cluster.put_component_template
+    elif what == "index_templates":
+        get = es.indices.get_index_template
+        put = es.indices.put_index_template
+    elif what == "ingest_pipelines":
+        get = es.ingest.get_pipeline
+        put = es.ingest.put_pipeline
+    else:
+        raise AssertionError()
+
+    try:
+        if what == "ingest_pipelines":
+            current = await get(id=name)
+            current_version = current[name].get("version", 1)
+        else:
+            current = await get(
+                name=name,
+                params={"filter_path": f"{what}.name,{what}.version"},
+            )
+            current_version = current[what][0].get("version", 1)
+    except NotFoundError:
+        current_version = 0
+
+    if current_version < body.get("version", 1):
+        if what == "ingest_pipelines":
+            return await put(id=name, body=body)
+        return await put(name=name, body=body)  # type: ignore[call-arg]
+
+    if current_version > body.get("version", 1):
+        LOGGER.warning(
+            "%s has version %s. The version in Elasticsearch is %s!",
+            path,
+            body.get("version", 1),
+            current_version,
+        )
+
+    return None
 
 
 def setup_redis(app: Application) -> None | Redis[str]:
@@ -895,9 +931,9 @@ def supervise() -> None:
         time.sleep(1)
 
 
-def main(  # noqa: C901
+def main(  # noqa: C901  # pragma: no cover
     config: BetterConfigParser | None = None,
-) -> None | int | str:  # pragma: no cover
+) -> int | str:
     """
     Start everything.
 
@@ -911,7 +947,7 @@ def main(  # noqa: C901
     install_signal_handler()
 
     args = parse_command_line_arguments()
-    config = parse_config(*args.config) if config is None else config
+    config = config or parse_config(*args.config)
 
     setup_logging(config)
 
@@ -1051,29 +1087,25 @@ def main(  # noqa: C901
             config.write(file)
 
     if not sockets:
-        return None
+        return 0
+
+    if perf8 and "PERF8" in os.environ:
+        loop.run_until_complete(perf8.enable())
 
     try:
         loop.run_forever()
         EVENT_SHUTDOWN.set()
     finally:
-        try:
+        try:  # pylint: disable=too-many-try-statements
             server.stop()
             loop.run_until_complete(asyncio.sleep(1))
-            loop.run_until_complete(
-                asyncio.wait_for(server.close_all_connections(), 5)
-            )
-
+            loop.run_until_complete(server.close_all_connections())
+            if perf8 and "PERF8" in os.environ:
+                loop.run_until_complete(perf8.disable())
             if redis := app.settings.get("REDIS"):
-                loop.run_until_complete(
-                    asyncio.wait_for(redis.close(close_connection_pool=True), 5)
-                )
-
+                loop.run_until_complete(redis.close(close_connection_pool=True))
             if elasticsearch := app.settings.get("ELASTICSEARCH"):
-                loop.run_until_complete(
-                    asyncio.wait_for(elasticsearch.close(), 5)
-                )
-
+                loop.run_until_complete(elasticsearch.close())
         finally:
             try:
                 _cancel_all_tasks(loop)
@@ -1083,4 +1115,4 @@ def main(  # noqa: C901
                 loop.close()
                 HEARTBEAT = 0
 
-    return None
+    return 0
