@@ -16,6 +16,7 @@
 from __future__ import annotations
 
 import os
+from typing import Final
 
 from tornado.web import RedirectHandler
 
@@ -32,7 +33,7 @@ from .quote_of_the_day import (
 from .quotes import QuoteAPIHandler, QuoteById, QuoteMainPage, QuoteRedirectAPI
 from .share import ShareQuote
 
-DIR = os.path.dirname(__file__)
+DIR: Final = os.path.dirname(__file__)
 
 
 def get_module_info() -> ModuleInfo:
