@@ -21,6 +21,8 @@ import math
 import os
 import sys
 import textwrap
+from collections.abc import Iterable
+from tempfile import TemporaryDirectory
 from typing import Any, ClassVar, Final
 
 from PIL import Image, ImageDraw, ImageFont
@@ -34,6 +36,11 @@ from .utils import (
     get_wrong_quotes,
 )
 
+try:
+    from unexpected_isaves.save_image import to_excel  # type: ignore[import]
+except ImportError:
+    to_excel = None
+
 LOGGER: Final = logging.getLogger(__name__)
 
 AUTHOR_MAX_WIDTH: Final[int] = 686
@@ -54,6 +61,28 @@ HOST_NAME_FONT: Final = ImageFont.truetype(
     size=23,
 )
 
+FILE_EXTENSIONS = {
+    "bmp": "bmp",
+    "gif": "gif",
+    "jfif": "jpeg",
+    "jpe": "jpeg",
+    "jpeg": "jpeg",
+    "jpg": "jpeg",
+    "jxl": "jxl",
+    "pdf": "pdf",
+    "png": "png",
+    "spi": "spider",
+    "tiff": "tiff",
+    "webp": "webp",
+    "xlsx": "xlsx",
+}
+
+if not to_excel:
+    del FILE_EXTENSIONS["xlsx"]
+
+if not hasattr(patches, "JXLImagePlugin"):
+    del FILE_EXTENSIONS["jxl"]
+
 
 def load_png(filename: str) -> Image.Image:
     """Load a PNG image into memory."""
@@ -119,7 +148,7 @@ def draw_text(  # pylint: disable=too-many-arguments
 
 def draw_lines(  # pylint: disable=too-many-arguments
     image: ImageDraw.ImageDraw,
-    lines: list[str],
+    lines: Iterable[str],
     y_start: int,
     max_w: int,
     max_h: int,
@@ -131,12 +160,12 @@ def draw_lines(  # pylint: disable=too-many-arguments
     for line in lines:
         width = font.getlength(line)
         draw_text(
-            image=image,
-            text=line,
-            x=padding_left + math.ceil((max_w - width) / 2),
-            y=y_start,
-            font=font,
-            stroke_width=stroke_width,
+            image,
+            line,
+            padding_left + math.ceil((max_w - width) / 2),
+            y_start,
+            font,
+            stroke_width,
         )
         y_start += max_h
     return y_start
@@ -151,6 +180,8 @@ def create_image(  # noqa: C901  # pylint: disable=too-complex
     source: None | str,
     file_type: str = "png",
     font: ImageFont.FreeTypeFont = FONT,
+    *,
+    wq_id: None | str = None,
 ) -> bytes:
     """Create an image with the given quote and author."""
     image = BACKGROUND_IMAGE.copy()
@@ -180,7 +211,8 @@ def create_image(  # noqa: C901  # pylint: disable=too-complex
         QUOTE_MAX_WIDTH,
         max_line_height,
         font,
-        stroke_width=1 if file_type == "4-color-gif" else 0,
+        0,
+        1 if file_type == "4-color-gif" else 0,
     )
 
     # draw author
@@ -202,18 +234,19 @@ def create_image(  # noqa: C901  # pylint: disable=too-complex
         max_line_height,
         font,
         10,
-        stroke_width=1 if file_type == "4-color-gif" else 0,
+        1 if file_type == "4-color-gif" else 0,
     )
 
     if y_text > IMAGE_HEIGHT and font is FONT:
         LOGGER.info("Using smaller font for quote %s", source)
         return create_image(
-            quote=quote,
-            author=author,
-            rating=rating,
-            source=source,
-            file_type=file_type,
-            font=FONT_SMALLER,
+            quote,
+            author,
+            rating,
+            source,
+            file_type,
+            FONT_SMALLER,
+            wq_id=wq_id,
         )
 
     # draw rating
@@ -221,12 +254,12 @@ def create_image(  # noqa: C901  # pylint: disable=too-complex
         _, y_off, width, height = FONT_SMALLER.getbbox(str(rating))
         y_rating = IMAGE_HEIGHT - 25 - height
         draw_text(
-            image=draw,
-            text=str(rating),
-            x=25,
-            y=y_rating,
-            font=FONT_SMALLER,  # always use same font for rating
-            stroke_width=1,
+            draw,
+            str(rating),
+            25,
+            y_rating,
+            FONT_SMALLER,  # always use same font for rating
+            1,
         )
         # draw rating image
         icon = NICHT_WITZIG_IMAGE if rating < 0 else WITZIG_IMAGE
@@ -243,62 +276,59 @@ def create_image(  # noqa: C901  # pylint: disable=too-complex
     if source:
         width, height = HOST_NAME_FONT.getbbox(source)[2:]
         draw_text(
-            image=draw,
-            text=source,
-            x=IMAGE_WIDTH - 5 - width,
-            y=IMAGE_HEIGHT - 5 - height,
-            font=HOST_NAME_FONT,
-            stroke_width=0,
+            draw,
+            source,
+            IMAGE_WIDTH - 5 - width,
+            IMAGE_HEIGHT - 5 - height,
+            HOST_NAME_FONT,
+            0,
         )
 
+    if to_excel and file_type == "xlsx":
+        with TemporaryDirectory() as tempdir_name:
+            filepath = os.path.join(tempdir_name, f"{wq_id or '0-0'}.xlsx")
+            to_excel(image, filepath, lower_image_size_by=10)
+            with open(filepath, "rb") as file:
+                return file.read()
+
     buffer = io.BytesIO()
     kwargs: dict[str, Any] = {
         "format": file_type,
         "optimize": True,
         "save_all": False,
     }
+
     if file_type == "4-color-gif":
         colors: list[tuple[int, tuple[int, int, int]]]
         colors = image.getcolors(2**16)  # type: ignore[assignment]
         colors.sort(reverse=True)
-        values: list[int] = []
+        palette = bytearray()
         for _, color in colors[:4]:
-            values.extend(color)
-        kwargs.update(format="gif", palette=bytearray(values))
+            palette.extend(color)
+        kwargs.update(format="gif", palette=palette)
     elif file_type == "jxl":
         kwargs.update(lossless=True)
     elif file_type == "tiff":
         kwargs.update(compression="zlib")
     elif file_type == "webp":
         kwargs.update(lossless=True)
+
     image.save(buffer, **kwargs)
     return buffer.getvalue()
 
 
-FILE_EXTENSIONS = {
-    "png": "png",
-    "gif": "gif",
-    "jpeg": "jpeg",
-    "jpg": "jpeg",
-    "jfif": "jpeg",
-    "jpe": "jpeg",
-    "webp": "webp",
-    "bmp": "bmp",
-    "pdf": "pdf",
-    "spi": "spider",
-    "tiff": "tiff",
-}
-
-if hasattr(patches, "JXLImagePlugin"):
-    FILE_EXTENSIONS["jxl"] = "jxl"
-
-
 class QuoteAsImage(QuoteReadyCheckHandler):
     """Quote as image request handler."""
 
-    POSSIBLE_CONTENT_TYPES: ClassVar[tuple[str, ...]] = (
-        *{f"image/{type}" for type in FILE_EXTENSIONS.values()},
-    )
+    POSSIBLE_CONTENT_TYPES: ClassVar[list[str]] = [  # type: ignore[assignment]
+        "text/html",
+        *{
+            f"image/{type}"
+            for type in FILE_EXTENSIONS.values()
+            if type not in {"pdf", "xlsx"}
+        },
+        "application/pdf",
+    ]
     RATELIMIT_GET_LIMIT: ClassVar[int] = 15
     IS_NOT_HTML: ClassVar[bool] = True
 
@@ -319,9 +349,19 @@ class QuoteAsImage(QuoteReadyCheckHandler):
             self.set_status(400, reason=reason)
             self.content_type = "text/plain"
             return await self.finish(reason)
+
         file_type = FILE_EXTENSIONS[file_extension]
-        self.handle_accept_header((f"image/{file_type}",))
-        self.set_header("Content-Type", f"image/{file_type}")
+
+        content_type = (
+            f"image/{file_type}"
+            if file_type not in {"pdf", "xlsx"}
+            else {"pdf": "application/pdf", "xlsx": "application/vnd.ms-excel"}[
+                file_type
+            ]
+        )
+
+        self.handle_accept_header((content_type,))
+        self.set_header("Content-Type", content_type)
 
         int_quote_id = int(quote_id)
         wrong_quote = (
@@ -336,8 +376,10 @@ class QuoteAsImage(QuoteReadyCheckHandler):
 
         self.set_header(
             "Content-Disposition",
-            f"inline; filename={self.request.host.replace('.', '-')}_z_"
-            f"{wrong_quote.get_id_as_str()}.{file_extension.lower()}",
+            (
+                f"inline; filename={self.request.host.replace('.', '-')}_z_"
+                f"{wrong_quote.get_id_as_str()}.{file_extension.lower()}"
+            ),
         )
 
         if head:
@@ -351,6 +393,7 @@ class QuoteAsImage(QuoteReadyCheckHandler):
 
         if file_type == "gif" and self.get_bool_argument("small", False):
             file_type = "4-color-gif"
+
         return await self.finish(
             create_image(
                 wrong_quote.quote.quote,
@@ -358,5 +401,10 @@ class QuoteAsImage(QuoteReadyCheckHandler):
                 wrong_quote.rating,
                 source,
                 file_type,
+                wq_id=wrong_quote.get_id_as_str(),
             )
         )
+
+
+if to_excel:
+    QuoteAsImage.POSSIBLE_CONTENT_TYPES.append("application/vnd.ms-excel")
