@@ -39,11 +39,11 @@ import orjson as json
 import regex
 import yaml
 from accept_types import get_best_match  # type: ignore[import]
-from elastic_enterprise_search import AppSearch  # type: ignore[import]
 from elasticsearch import AsyncElasticsearch
 from elasticsearch.exceptions import ElasticsearchException
 from redis.asyncio import Redis
 from tornado.web import (
+    Finish,
     GZipContentEncoding,
     HTTPError,
     MissingArgumentError,
@@ -57,8 +57,8 @@ from .. import (
     ORJSON_OPTIONS,
     pytest_is_running,
 )
+from .decorators import is_authorized
 from .static_file_handling import FILE_HASHES_DICT
-from .token import InvalidTokenError, parse_token
 from .utils import (
     THEMES,
     BumpscosityValue,
@@ -66,7 +66,6 @@ from .utils import (
     OpenMojiValue,
     Permission,
     add_args_to_url,
-    anonymize_ip,
     bool_to_str,
     geoip,
     hash_bytes,
@@ -76,11 +75,17 @@ from .utils import (
     str_to_bool,
 )
 
+if sys.version_info >= (3, 12):
+    from typing import override
+else:
+    from typing_extensions import override
+
 LOGGER: Final = logging.getLogger(__name__)
 
 TEXT_CONTENT_TYPES: Final[set[str]] = {
     "application/javascript",
     "application/json",
+    "application/vnd.asozial.dynload+json",
     "application/x-ndjson",
     "application/xml",
     "application/yaml",
@@ -93,7 +98,7 @@ class BaseRequestHandler(RequestHandler):
     # pylint: disable=too-many-instance-attributes, too-many-public-methods
 
     ELASTIC_RUM_URL: ClassVar[str] = (
-        "/@elastic/apm-rum@^5/dist/bundles/elastic-apm-rum"
+        "/@elastic/apm-rum@5.12.0/dist/bundles/elastic-apm-rum"
         f".umd{'.min' if not sys.flags.dev_mode else ''}.js"
     )
 
@@ -102,9 +107,6 @@ class BaseRequestHandler(RequestHandler):
     MAX_BODY_SIZE: ClassVar[None | int] = None
     ALLOWED_METHODS: ClassVar[tuple[str, ...]] = ("GET",)
     POSSIBLE_CONTENT_TYPES: ClassVar[tuple[str, ...]] = ()
-    REQUIRED_PERMISSION: ClassVar[None | Permission] = None
-    # the following should be False on security relevant endpoints
-    ALLOW_COOKIE_AUTHENTICATION: ClassVar[bool] = True
 
     module_info: ModuleInfo
     # info about page, can be overridden in module_info
@@ -114,7 +116,6 @@ class BaseRequestHandler(RequestHandler):
 
     active_origin_trials: set[bytes]
     content_type: None | str = None
-    auth_failed: bool = False
     apm_script: None | str
     crawler: bool = False
     now: datetime
@@ -129,29 +130,24 @@ class BaseRequestHandler(RequestHandler):
         """Return whether APM is enabled."""
         return bool(self.settings.get("ELASTIC_APM", {}).get("ENABLED"))
 
-    @property
-    def app_search(self) -> None | AppSearch:
-        """Get the App Search client from the settings."""
-        return self.settings.get("APP_SEARCH")
-
-    @property
-    def app_search_engine(self) -> str:
-        """Get the App Search engine from the settings."""
-        return self.settings.get("APP_SEARCH_ENGINE", NAME.removesuffix("-dev"))
-
+    @override
     def compute_etag(self) -> None | str:
         """Compute ETag with Base85 encoding."""
         if not self.COMPUTE_ETAG:
             return None
-        return f'"{hash_bytes(*self._write_buffer)}"'
+        return f'"{hash_bytes(*self._write_buffer)}"'  # noqa: B907
 
+    @override
     def data_received(self, chunk: bytes) -> None | Awaitable[None]:
         """Do nothing."""
 
     @property
     def dump(self) -> Callable[[Any], str | bytes]:
         """Get the function for dumping the output."""
-        if self.content_type == "application/json":
+        if self.content_type in {
+            "application/json",
+            "application/vnd.asozial.dynload+json",
+        }:
             option = ORJSON_OPTIONS
             if self.get_bool_argument("pretty", False):
                 option |= json.OPT_INDENT_2
@@ -178,6 +174,7 @@ class BaseRequestHandler(RequestHandler):
         """Get the Elasticsearch prefix from the settings."""
         return self.settings.get("ELASTICSEARCH_PREFIX", NAME)
 
+    @override
     def finish(
         self, chunk: None | str | bytes | dict[str, Any] = None
     ) -> Future[None]:
@@ -211,7 +208,7 @@ class BaseRequestHandler(RequestHandler):
 
         return super().finish()
 
-    def fix_url(  # noqa: C901
+    def fix_url(  # noqa: C901  # pylint: disable=too-complex
         self,
         url: None | str | SplitResult = None,
         new_path: None | str = None,
@@ -234,6 +231,7 @@ class BaseRequestHandler(RequestHandler):
             query_args.update(
                 no_3rd_party=None,
                 theme=None,
+                effects=None,
                 dynload=None,
                 openmoji=None,
                 bumpscosity=None,
@@ -241,6 +239,7 @@ class BaseRequestHandler(RequestHandler):
         else:
             query_args.setdefault("no_3rd_party", self.get_no_3rd_party())
             query_args.setdefault("theme", self.get_theme())
+            query_args.setdefault("effects", self.get_effects())
             query_args.setdefault("dynload", self.get_dynload())
             query_args.setdefault("openmoji", self.get_openmoji())
             query_args.setdefault("bumpscosity", self.get_bumpscosity())
@@ -248,6 +247,8 @@ class BaseRequestHandler(RequestHandler):
                 query_args["no_3rd_party"] = None
             if query_args["theme"] == self.get_saved_theme():
                 query_args["theme"] = None
+            if query_args["effects"] == self.get_saved_effects():
+                query_args["effects"] = None
             if query_args["dynload"] == self.get_saved_dynload():
                 query_args["dynload"] = None
             if query_args["openmoji"] == self.get_saved_openmoji():
@@ -307,20 +308,20 @@ class BaseRequestHandler(RequestHandler):
             raise HTTPError(400, f"{value} is not a boolean") from err
 
     def get_bumpscosity(self) -> BumpscosityValue:
-        """Get the saved value for the bumpscosity."""
+        """Get the value for the bumpscosity."""
         if spam := self.get_argument("bumpscosity", ""):
             return parse_bumpscosity(spam)
         return self.get_saved_bumpscosity()
 
     def get_display_theme(self) -> str:
         """Get the theme currently displayed."""
-        if "random" not in (theme := self.get_theme()):
+        if (theme := self.get_theme()).split("_")[0] != "random":
             return theme
 
-        ignore_themes = ["random", "random-dark"]
+        ignore_themes = ["random", "random_dark", "christmas"]
 
-        if theme == "random-dark":
-            ignore_themes.extend(("light", "light-blue", "fun"))
+        if theme == "random_dark":
+            ignore_themes.extend(("light", "light_blue", "fun"))
 
         return random.choice(  # nosec: B311
             tuple(theme for theme in THEMES if theme not in ignore_themes)
@@ -330,6 +331,10 @@ class BaseRequestHandler(RequestHandler):
         """Return the dynload query argument as boolean."""
         return self.get_bool_argument("dynload", self.get_saved_dynload())
 
+    def get_effects(self) -> bool:
+        """Return the effects query argument as boolean."""
+        return self.get_bool_argument("effects", self.get_saved_effects())
+
     def get_error_message(self, **kwargs: Any) -> str:
         """
         Get the error message and return it.
@@ -446,6 +451,10 @@ class BaseRequestHandler(RequestHandler):
         """Get the saved value for dynload."""
         return str_to_bool(self.get_cookie("dynload"), False)
 
+    def get_saved_effects(self) -> bool:
+        """Get the saved value for effects."""
+        return str_to_bool(self.get_cookie("effects"), True)
+
     def get_saved_no_3rd_party(self) -> bool:
         """Get the saved value for no_3rd_party."""
         return str_to_bool(
@@ -460,18 +469,24 @@ class BaseRequestHandler(RequestHandler):
 
     def get_saved_theme(self) -> str:
         """Get the theme saved in the cookie."""
-        if (theme := self.get_cookie("theme")) in THEMES:
+        if (
+            theme := cast(str, self.get_cookie("theme", ""))
+            .replace("-", "_")
+            .lower()
+        ) in THEMES:
             return theme
         return "default"
 
     def get_theme(self) -> str:
         """Get the theme currently selected."""
-        if (theme := self.get_argument("theme", None)) in THEMES:
+        if (
+            theme := self.get_argument("theme", "").replace("-", "_").lower()
+        ) in THEMES:
             return theme
         return self.get_saved_theme()
 
     async def get_time(self) -> datetime:
-        """Get the start time of the request in the users timezone."""
+        """Get the start time of the request in the users' timezone."""
         tz: tzinfo = timezone.utc  # pylint: disable=invalid-name
         try:
             geoip = await self.geoip()  # pylint: disable=redefined-outer-name
@@ -496,8 +511,7 @@ class BaseRequestHandler(RequestHandler):
 
         user_id = cookie.decode("UTF-8") if cookie else str(uuid.uuid4())
 
-        # save it in cookie or reset expiry date
-        if not self.get_secure_cookie(
+        if not self.get_secure_cookie(  # save it in cookie or reset expiry date
             "user_id", max_age_days=30, min_version=2
         ):
             self.set_secure_cookie(
@@ -510,8 +524,8 @@ class BaseRequestHandler(RequestHandler):
 
         return user_id
 
-    def handle_accept_header(
-        self, possible_content_types: tuple[str, ...]
+    def handle_accept_header(  # pylint: disable=inconsistent-return-statements
+        self, possible_content_types: tuple[str, ...], strict: bool = True
     ) -> None:
         """Handle the Accept header and set `self.content_type`."""
         if not possible_content_types:
@@ -521,11 +535,20 @@ class BaseRequestHandler(RequestHandler):
             possible_content_types,
         )
         if content_type is None:
-            self.raise_non_acceptable(possible_content_types)
-            return
+            if strict:
+                return self.handle_not_acceptable(possible_content_types)
+            content_type = possible_content_types[0]
         self.content_type = content_type
         self.set_content_type_header()
 
+    def handle_not_acceptable(
+        self, possible_content_types: tuple[str, ...]
+    ) -> None:
+        """Only call this if we cannot respect the Accept header."""
+        self.clear_header("Content-Type")
+        self.set_status(406)
+        raise Finish("\n".join(possible_content_types) + "\n")
+
     def head(self, *args: Any, **kwargs: Any) -> None | Awaitable[None]:
         """Handle HEAD requests."""
         if self.get.__module__ == "tornado.web":
@@ -536,6 +559,7 @@ class BaseRequestHandler(RequestHandler):
         kwargs["head"] = True
         return self.get(*args, **kwargs)
 
+    @override
     def initialize(
         self,
         *,
@@ -561,51 +585,13 @@ class BaseRequestHandler(RequestHandler):
                 self.request.path
             ).description
 
-    def is_authorized(self, permission: Permission) -> None | bool:
+    def is_authorized(
+        self, permission: Permission, allow_cookie_auth: bool = True
+    ) -> bool | None:
         """Check whether the request is authorized."""
-        api_secrets: dict[str | None, Permission] = self.settings.get(
-            "TRUSTED_API_SECRETS", {}
-        )
-        auth_secret: str | bytes | None = self.settings.get("AUTH_TOKEN_SECRET")
-
-        def keydecode(token: str) -> None | Permission:
-            if auth_secret:
-                with contextlib.suppress(InvalidTokenError):
-                    return parse_token(token, secret=auth_secret).permissions
-            try:
-                return api_secrets.get(b64decode(token).decode("UTF-8"))
-            except ValueError:
-                return None
-
-        permissions: tuple[None | Permission, ...] = (
-            *(
-                (
-                    keydecode(_[7:])
-                    if _.lower().startswith("bearer ")
-                    else api_secrets.get(_)
-                )
-                for _ in self.request.headers.get_list("Authorization")
-            ),
-            *(keydecode(_) for _ in self.get_arguments("access_token")),
-            *(api_secrets.get(_) for _ in self.get_arguments("key")),
-            keydecode(cast(str, self.get_cookie("access_token", "")))
-            if self.ALLOW_COOKIE_AUTHENTICATION
-            else None,
-            api_secrets.get(self.get_cookie("key", None))
-            if self.ALLOW_COOKIE_AUTHENTICATION
-            else None,
-        )
-
-        if all(perm is None for perm in permissions):
-            return None
-
-        result = Permission(0)
-        for perm in permissions:
-            if perm:
-                result |= perm
-
-        return permission in result
+        return is_authorized(self, permission, allow_cookie_auth)
 
+    @override
     def options(self, *args: Any, **kwargs: Any) -> None:
         """Handle OPTIONS requests."""
         # pylint: disable=unused-argument
@@ -639,9 +625,10 @@ class BaseRequestHandler(RequestHandler):
         self.active_origin_trials.add(data)
         return True
 
+    @override
     async def prepare(self) -> None:  # noqa: C901
         """Check authorization and call self.ratelimit()."""
-        # pylint: disable=invalid-overridden-method, too-complex, too-many-branches
+        # pylint: disable=invalid-overridden-method, too-complex
         if not self.ALLOW_COMPRESSION:
             for transform in self._transforms:
                 if isinstance(transform, GZipContentEncoding):
@@ -666,28 +653,6 @@ class BaseRequestHandler(RequestHandler):
                 self.set_cookie("c", "s", expires_days=days / 24, path="/")
 
         if self.request.method != "OPTIONS":
-            required_permission = self.REQUIRED_PERMISSION
-            required_permission_for_method = getattr(
-                self, f"REQUIRED_PERMISSION_{self.request.method}", None
-            )
-
-            if required_permission is None:
-                required_permission = required_permission_for_method
-            elif required_permission_for_method is not None:
-                required_permission |= required_permission_for_method
-
-            if not (
-                required_permission is None
-                or (is_authorized := self.is_authorized(required_permission))
-            ):
-                self.auth_failed = True
-                LOGGER.warning(
-                    "Unauthorized access to %s from %s",
-                    self.request.path,
-                    anonymize_ip(self.request.remote_ip),
-                )
-                raise HTTPError(401 if is_authorized is None else 403)
-
             if (
                 self.MAX_BODY_SIZE is not None
                 and len(self.request.body) > self.MAX_BODY_SIZE
@@ -702,14 +667,6 @@ class BaseRequestHandler(RequestHandler):
             if not await self.ratelimit(True):
                 await self.ratelimit()
 
-    def raise_non_acceptable(
-        self, possible_content_types: tuple[str, ...]
-    ) -> None:
-        """Only call this if we cannot respect the Accept header."""
-        self.clear_header("Content-Type")
-        self.set_status(406)
-        self.finish("\n".join(possible_content_types) + "\n")
-
     async def ratelimit(self, global_ratelimit: bool = False) -> bool:
         """Take b1nzy to space using Redis."""
         if (
@@ -722,8 +679,10 @@ class BaseRequestHandler(RequestHandler):
 
         if not EVENT_REDIS.is_set():
             LOGGER.warning(
-                "Ratelimits are enabled, but Redis is not available. "
-                "This can happen shortly after starting the website.",
+                (
+                    "Ratelimits are enabled, but Redis is not available. "
+                    "This can happen shortly after starting the website."
+                ),
             )
             raise HTTPError(503)
 
@@ -809,13 +768,14 @@ class BaseRequestHandler(RequestHandler):
 
     def set_content_type_header(self) -> None:
         """Set the Content-Type header based on `self.content_type`."""
-        if str(self.content_type).startswith("text/"):  # RFC2616 3.7.1
+        if str(self.content_type).startswith("text/"):  # RFC 2616 (3.7.1)
             self.set_header(
                 "Content-Type", f"{self.content_type};charset=utf-8"
             )
         elif self.content_type is not None:
             self.set_header("Content-Type", self.content_type)
 
+    @override
     def set_cookie(  # pylint: disable=too-many-arguments
         self,
         name: str,
@@ -891,13 +851,17 @@ class BaseRequestHandler(RequestHandler):
             ),
         )
 
+    @override
     def set_default_headers(self) -> None:
         """Set default headers."""
         self.set_csp_header()
         self.active_origin_trials = set()
         if self.settings.get("REPORTING"):
             endpoint = self.get_reporting_api_endpoint()
-            self.set_header("Reporting-Endpoints", f'default="{endpoint}"')
+            self.set_header(
+                "Reporting-Endpoints",
+                f'default="{endpoint}"',  # noqa: B907
+            )
             self.set_header(
                 "Report-To",
                 json.dumps(
@@ -952,8 +916,6 @@ class BaseRequestHandler(RequestHandler):
                         f"X-Permission-{permission.name}",
                         bool_to_str(bool(self.is_authorized(permission))),
                     )
-        if self.auth_failed:
-            self.set_header("WWW-Authenticate", "Bearer")
         self.origin_trial(
             "AjM7i7vhQFI2RUcab3ZCsJ9RESLDD9asdj0MxpwxHXXtETlsm8dEn+HSd646oPr1dKjn+EcNEj8uV3qFGJzObgsAAAB3eyJvcmlnaW4iOiJodHRwczovL2Fzb3ppYWwub3JnOjQ0MyIsImZlYXR1cmUiOiJTZW5kRnVsbFVzZXJBZ2VudEFmdGVyUmVkdWN0aW9uIiwiZXhwaXJ5IjoxNjg0ODg2Mzk5LCJpc1N1YmRvbWFpbiI6dHJ1ZX0="  # noqa: B950  # pylint: disable=line-too-long, useless-suppression
         )
@@ -968,6 +930,7 @@ class BaseRequestHandler(RequestHandler):
             == inspect.Parameter.KEYWORD_ONLY
         )
 
+    @override
     def write(self, chunk: str | bytes | dict[str, Any]) -> None:
         """Write the given chunk to the output buffer.
 
