@@ -23,24 +23,21 @@ import pathlib
 import random
 import time
 from base64 import b85encode
-from collections.abc import Callable, Iterable, Sequence
+from collections.abc import (
+    Awaitable,
+    Callable,
+    Generator,
+    Iterable,
+    Sequence,
+    Set,
+)
 from configparser import ConfigParser
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import IntFlag
 from functools import cache
 from ipaddress import IPv4Address, IPv6Address, ip_address, ip_network
-from typing import (
-    IO,
-    Any,
-    Final,
-    Literal,
-    TypeAlias,
-    TypeVar,
-    Union,
-    cast,
-    get_args,
-)
+from typing import IO, Any, Final, Literal, TypeVar, Union, cast, get_args
 from urllib.parse import SplitResult, parse_qsl, urlencode, urlsplit, urlunsplit
 
 import elasticapm  # type: ignore[import]
@@ -57,20 +54,22 @@ from .. import STATIC_DIR
 
 T = TypeVar("T")
 
+T_Val = TypeVar("T_Val")  # pylint: disable=invalid-name
+
 TOptionalStr = TypeVar("TOptionalStr", None, str)
 
 # pylint: disable=consider-alternative-union-syntax
-Handler: TypeAlias = Union[
+Handler = Union[
     tuple[str, type[RequestHandler]],
     tuple[str, type[RequestHandler], dict[str, Any]],
     tuple[str, type[RequestHandler], dict[str, Any], str],
 ]
 
-BumpscosityValue: TypeAlias = Literal[0, 1, 12, 50, 76, 100, 1000]
+OpenMojiValue = Literal[False, "img"]  # , "font"]
+BumpscosityValue = Literal[0, 1, 12, 50, 76, 100, 1000]
 BUMPSCOSITY_VALUES: Final[tuple[BumpscosityValue, ...]] = get_args(
     BumpscosityValue
 )
-OpenMojiValue: TypeAlias = Literal[False, "img"]  # , "font"]
 
 IP_HASH_SALT = {
     "date": datetime.utcnow().date(),
@@ -106,6 +105,20 @@ SUS_PATHS: Final[set[str]] = {
 }
 
 
+class AwaitableValue(Awaitable[T_Val]):
+    # pylint: disable=too-few-public-methods
+    """An awaitable that always returns the same value."""
+
+    def __await__(self) -> Generator[None, None, T_Val]:
+        """Return an iterator returning the value."""
+        yield
+        return self._value
+
+    def __init__(self, value: T_Val) -> None:
+        """Set the value."""
+        self._value = value
+
+
 class Permission(IntFlag):
     """Permissions for accessing restricted stuff."""
 
@@ -259,7 +272,7 @@ class Timer:
 
 
 @cache
-def add_args_to_url(url: str | SplitResult, **kwargs: dict[str, Any]) -> str:
+def add_args_to_url(url: str | SplitResult, **kwargs: Any) -> str:
     # pylint: disable=confusing-consecutive-elif
     """Add query arguments to a URL."""
     if isinstance(url, str):
@@ -357,7 +370,7 @@ def country_code_to_flag(code: str) -> str:
 
 def create_emoji_html(emoji: str, emoji_url: str) -> str:
     """Create an HTML element that can be used to display an emoji."""
-    return f'<img src="{emoji_url}" alt="{emoji}" class="emoji">'
+    return f"<img src={emoji_url!r} alt={emoji!r} class='emoji'>"
 
 
 def emoji2code(emoji: str) -> str:
@@ -527,7 +540,7 @@ def get_themes() -> tuple[str, ...]:
     return (
         *(file[:-4] for file in files if file.endswith(".css")),
         "random",  # add random to the list of themes
-        "random-dark",
+        "random_dark",
     )
 
 
@@ -578,7 +591,7 @@ def length_of_match(match: regex.Match[Any]) -> int:
     return match.end() - match.start()
 
 
-def n_from_set(set_: set[T] | frozenset[T], n: int) -> set[T]:
+def n_from_set(set_: Set[T], n: int) -> set[T]:
     """Get and return n elements of the set as a new set."""
     # pylint: disable=invalid-name
     new_set = set()
